<p align="center">
  <img width="200" src="https://raw.githubusercontent.com/xataio/company/main/logo/non-resizable/for-light-backgrounds/colored-with-text.png#gh-light-mode-only" />
  <img width="200" src="https://raw.githubusercontent.com/xataio/company/main/logo/non-resizable/for-dark-backgrounds/colored-with-text.png#gh-dark-mode-only" />
</p>

# Python SDK for Xata

[![Documentation Status](https://readthedocs.org/projects/xata-py/badge/?version=latest)](https://xata-py.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/xata.svg)](https://badge.fury.io/py/xata)

Simple Python client for xata.io databases. Currently work in progress.

Xata is a Serverless Database that is as easy to use as a spreadsheet, has the
data integrity of PostgreSQL, and the search and analytics functionality of
Elasticsearch.

The Python SDK uses type annotations and requires Python 3.8 or higher.

To install, run:

```
pip install xata
```

To learn more about Xata, visit [xata.io](https://xata.io).

- Python client documentation: https://xata-py.readthedocs.io
- API Reference: https://xata-py.readthedocs.io/en/latest/api.html
